@@ -105,7 +105,7 @@ def assemble(lines):
                         instruction = instruction_map[value.capitalize()](a, b)
 
                     # One param
-                    elif instruction in ['ldg', 'setg', 'nop']:
+                    elif instruction in ['ldg', 'setg']:
                         _, a = tokens.next()
                         instruction = instruction_map[value.capitalize()](a)
 
@@ -151,3 +151,55 @@ def ascii_binary_to_real_binary(ascii_binary):
         [chr(int('0b'+ascii_binary[i:i+8], 2))
             for i in range(0, len(ascii_binary), 8)]
     )
+
+
+def ascii_binary_to_vhdl_code(ascii_binary):
+
+    def zero_pad(string, length):
+        return string + "0" * max(length - len(string), 0)
+
+    print "library ieee;"
+    print "use ieee.std_logic_1164.all;"
+    print "use ieee.numeric_std.all;"
+    print ""
+    print "entity FakeInstMem is"
+    print "    port("
+    print "        IMEM_CE_HI      : in   STD_LOGIC;"
+    print "        IMEM_CE_LO      : in   STD_LOGIC;"
+    print "        IMEM_WE_HI      : in   STD_LOGIC;"
+    print "        IMEM_WE_LO      : in   STD_LOGIC;"
+    print "        IMEM_DATA_HI    : out STD_LOGIC_VECTOR(16-1 downto 0);"
+    print "        IMEM_DATA_LO    : out STD_LOGIC_VECTOR(16-1 downto 0);"
+    print "        IMEM_ADDR       : in   STD_LOGIC_VECTOR(19-1 downto 0);"
+    print "        IMEM_LBUB       : in   STD_LOGIC"
+    print "    );"
+    print "end FakeInstMem;"
+    print ""
+    print "architecture behavioral of FakeInstMem is"
+    print "type mem is array (0 to 2**19 - 1)",
+    "of std_logic_vector(16-1 downto 0);"
+    print ""
+    print "constant hi : mem := ("
+    for i in range(2**19):
+        print "    " + str(i) + "  => \"" + \
+            zero_pad(ascii_binary[i * 32: i * 32 + 16], 16) + "\","
+    print ");"
+
+    print "constant lo : mem := ("
+    for i in range(2**19):
+        print "    " + str(i) + "  => \"" + \
+            zero_pad(ascii_binary[i * 32 + 16: i * 32 + 32], 16) + "\","
+    print ");"
+    print ""
+    print "begin"
+    print ""
+    print "    process (address)"
+    print "    begin"
+    print "        case address is"
+    for i in range(2**19):
+        print "            when \"" + zero_pad(bin(i)[2:], 19) + \
+            "\" => data <= my_rom(" + str(i) + ");"
+    print "            when others => data <= \"" + ("0"*32) + "\";"
+    print "        end case;"
+    print "    end process;"
+    print "end architecture behavioral;"
